from odoo import api, models, fields
from odoo.osv import expression


class CustomRepairAccountAnalyticLine(models.Model):
    _inherit = 'account.analytic.line'

    repair_id = fields.Many2one(
        'repair.order', 
        string="Orden de reparación",
        ondelete='cascade'
    )

    def _domain_project_id(self):
        domain = [('allow_timesheets', '=', True)]
        if not self.user_has_groups('hr_timesheet.group_timesheet_manager'):
            return expression.AND([domain,
                ['|', ('privacy_visibility', '!=', 'followers'), ('message_partner_ids', 'in', [self.env.user.partner_id.id])]
            ])
        return domain
    
    def _default_project_id(self):
        # Reemplaza con la lógica para obtener el ID del proyecto por defecto
        return self.env['project.project'].search([], limit=1).id

    project_id = fields.Many2one(
        'project.project', 'Project', compute='_compute_project_id', default=_default_project_id, store=True, readonly=False,
        domain=_domain_project_id)
    
    @api.depends('task_id', 'task_id.project_id')
    def _compute_project_id(self):
        for line in self:
            if not line.task_id.project_id or line.project_id == line.task_id.project_id:
                continue
            line.project_id = line.task_id.project_id
