from odoo import api, fields, models, _
#from odoo.exceptions import ValidationError, UserError
#from functools import wraps

#import re

class CustomRepairProductTemplateInherit(models.Model):
    _inherit = 'product.template'

    type = fields.Selection(
        selection_add=[('repair', 'To repair')],
    )

    detailed_type = fields.Selection(
        selection_add=[('repair', 'To repair')],
        ondelete={'repair': 'set default'}
    )

    currency_id = fields.Many2one(
        'res.currency', 'Currency', store=True, readonly=False, compute='_compute_currency_id')
    cost_currency_id = fields.Many2one(
        'res.currency', 'Cost Currency', store=True, readonly=False, compute='_compute_cost_currency_id')

    autogenerated = fields.Boolean('Auto Generated Product', default=False)

    is_operator = fields.Boolean(
        string='Is Operator',
        compute='_compute_is_operator',
        store=False
    )

    storage_location = fields.Many2one(
        'stock.location', 'Storage Location', store=True, readonly=False)
    
    invoice_service_product = fields.Boolean('Es servicio de cargo en factura?', default=False)

    @api.depends_context('uid')
    def _compute_is_operator(self):
        for product in self:
            user = self.env.user
            product.is_operator = user.has_group('custom_repair.group_operario_reparacion')
            '''
            employee = self.env['hr.employee'].search([('user_id', '=', user.id)], limit=1)
            product.is_operator = employee.repair_employee_type == 'operario' if employee else False
            '''
    
    def name_get(self):
        result = []
        for product in self:
            name = product.name
            if product.barcode:
                name = "[%s] %s" % (product.barcode, name)
            elif product.default_code:
                name = "[%s] %s" % (product.default_code, name)
            result.append((product.id, name))
        return result

class CustomRepairProductInherit(models.Model):
    _inherit = 'product.product'

    def name_get(self):
        result = []
        for product in self:
            name = product.name
            if product.barcode:
                name = "[%s] %s" % (product.barcode, name)
            elif product.default_code:
                name = "[%s] %s" % (product.default_code, name)
            result.append((product.id, name))
        return result
    
    @api.model
    def name_search(self, name, args=None, operator='ilike', limit=100):
        args = args or []
        domain = []
        if name:
            domain = ['|', '|', ('barcode', operator, name), ('default_code', operator, name), ('name', operator, name)]
        products = self.search(domain + args, limit=limit)
        return products.name_get()
