# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.


from collections import defaultdict
from odoo import _, api, fields, models
from odoo.exceptions import UserError

class ProductLabelLayout(models.TransientModel):
    _inherit = 'product.label.layout'

    print_format = fields.Selection(selection_add=[
        ('2_7_loc', 'Etiqueta con ubicación'),
    ], ondelete={'2_7_loc': 'set default'})

    def _prepare_report_data(self):
        if '2_7_loc' in self.print_format:
            xml_id = 'custom_repair.label_product_product'

            active_model = ''
            if self.product_tmpl_ids:
                products = self.product_tmpl_ids.ids
                active_model = 'product.template'
            elif self.product_ids:
                products = self.product_ids.ids
                active_model = 'product.product'
            else:
                raise UserError(_("No product to print, if the product is archived please unarchive it before printing its label."))

            # Build data to pass to the report
            data = {
                'active_model': active_model,
                'quantity_by_product': {p: self.custom_quantity for p in products},
                'layout_wizard': self.id,
                'price_included': 'xprice' in self.print_format,
            }
        else:
            xml_id, data = super(ProductLabelLayout, self)._prepare_report_data()
        
        return xml_id, data

    def process(self):
        report_action = super(ProductLabelLayout, self).process()
        return report_action